@@ -1,6 +1,6 @@
 /*
  * ProFTPD - FTP server daemon
- * Copyright (c) 2020 The ProFTPD Project team
+ * Copyright (c) 2020-2023 The ProFTPD Project team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,8 +28,8 @@
 #include "buildstamp.h"
 
 /* Application version (in various forms) */
-#define PROFTPD_VERSION_NUMBER		0x0001030705
-#define PROFTPD_VERSION_TEXT		"1.3.7"
+#define PROFTPD_VERSION_NUMBER		0x0001030806
+#define PROFTPD_VERSION_TEXT		"1.3.8a"
 
 /* Module API version */
 #define PR_MODULE_API_VERSION		0x20
@@ -39,6 +39,6 @@ unsigned long pr_version_get_number(void);
 const char *pr_version_get_str(void);
 
 /* PR_STATUS is reported by --version-status -- don't ask why */
-#define PR_STATUS          		"(stable)"
+#define PR_STATUS          		"(maint)"
 
 #endif /* PR_VERSION_H */
