@@ -50,65 +50,65 @@ START_TEST (stash_add_symbol_test) {
   authtable authtab;
   
   res = pr_stash_add_symbol(0, NULL);
-  fail_unless(res == -1, "Failed to handle null arguments");
-  fail_unless(errno == EINVAL, "Failed to set errno to EINVAL, got %d (%s)",
+  ck_assert_msg(res == -1, "Failed to handle null arguments");
+  ck_assert_msg(errno == EINVAL, "Failed to set errno to EINVAL, got %d (%s)",
     errno, strerror(errno));
 
   res = pr_stash_add_symbol(0, "Foo");
-  fail_unless(res == -1, "Failed to handle bad type");
-  fail_unless(errno == EINVAL, "Failed to set errno to EINVAL, got %d (%s)",
+  ck_assert_msg(res == -1, "Failed to handle bad type");
+  ck_assert_msg(errno == EINVAL, "Failed to set errno to EINVAL, got %d (%s)",
     errno, strerror(errno));
 
   memset(&conftab, 0, sizeof(conftab));
   res = pr_stash_add_symbol(PR_SYM_CONF, &conftab);
-  fail_unless(res == -1, "Failed to handle null conf name");
-  fail_unless(errno == EPERM, "Failed to set errno to EPERM, got %d (%s)",
+  ck_assert_msg(res == -1, "Failed to handle null conf name");
+  ck_assert_msg(errno == EPERM, "Failed to set errno to EPERM, got %d (%s)",
     errno, strerror(errno));
 
   memset(&cmdtab, 0, sizeof(cmdtab));
   res = pr_stash_add_symbol(PR_SYM_CMD, &cmdtab);
-  fail_unless(res == -1, "Failed to handle null cmd name");
-  fail_unless(errno == EPERM, "Failed to set errno to EPERM, got %d (%s)",
+  ck_assert_msg(res == -1, "Failed to handle null cmd name");
+  ck_assert_msg(errno == EPERM, "Failed to set errno to EPERM, got %d (%s)",
     errno, strerror(errno));
 
   memset(&authtab, 0, sizeof(authtab));
   res = pr_stash_add_symbol(PR_SYM_AUTH, &authtab);
-  fail_unless(res == -1, "Failed to handle null auth name");
-  fail_unless(errno == EPERM, "Failed to set errno to EPERM, got %d (%s)",
+  ck_assert_msg(res == -1, "Failed to handle null auth name");
+  ck_assert_msg(errno == EPERM, "Failed to set errno to EPERM, got %d (%s)",
     errno, strerror(errno));
 
   memset(&hooktab, 0, sizeof(hooktab));
   res = pr_stash_add_symbol(PR_SYM_HOOK, &hooktab);
-  fail_unless(res == -1, "Failed to handle null hook name");
-  fail_unless(errno == EPERM, "Failed to set errno to EPERM, got %d (%s)",
+  ck_assert_msg(res == -1, "Failed to handle null hook name");
+  ck_assert_msg(errno == EPERM, "Failed to set errno to EPERM, got %d (%s)",
     errno, strerror(errno));
 
   memset(&conftab, 0, sizeof(conftab));
   conftab.directive = pstrdup(p, "");
   res = pr_stash_add_symbol(PR_SYM_CONF, &conftab);
-  fail_unless(res == -1, "Failed to handle empty conf name");
-  fail_unless(errno == EPERM, "Failed to set errno to EPERM, got %d (%s)",
+  ck_assert_msg(res == -1, "Failed to handle empty conf name");
+  ck_assert_msg(errno == EPERM, "Failed to set errno to EPERM, got %d (%s)",
     errno, strerror(errno));
 
   memset(&conftab, 0, sizeof(conftab));
   conftab.directive = pstrdup(p, "Foo");
   res = pr_stash_add_symbol(PR_SYM_CONF, &conftab);
-  fail_unless(res == 0, "Failed to add CONF symbol: %s", strerror(errno));
+  ck_assert_msg(res == 0, "Failed to add CONF symbol: %s", strerror(errno));
 
   memset(&cmdtab, 0, sizeof(cmdtab));
   cmdtab.command = pstrdup(p, "Foo");
   res = pr_stash_add_symbol(PR_SYM_CMD, &cmdtab);
-  fail_unless(res == 0, "Failed to add CMD symbol: %s", strerror(errno));
+  ck_assert_msg(res == 0, "Failed to add CMD symbol: %s", strerror(errno));
 
   memset(&authtab, 0, sizeof(authtab));
   authtab.name = pstrdup(p, "Foo");
   res = pr_stash_add_symbol(PR_SYM_AUTH, &authtab);
-  fail_unless(res == 0, "Failed to add AUTH symbol: %s", strerror(errno));
+  ck_assert_msg(res == 0, "Failed to add AUTH symbol: %s", strerror(errno));
 
   memset(&hooktab, 0, sizeof(hooktab));
   hooktab.command = pstrdup(p, "Foo");
   res = pr_stash_add_symbol(PR_SYM_HOOK, &hooktab);
-  fail_unless(res == 0, "Failed to add HOOK symbol: %s", strerror(errno));
+  ck_assert_msg(res == 0, "Failed to add HOOK symbol: %s", strerror(errno));
 }
 END_TEST
 
@@ -120,89 +120,89 @@ START_TEST (stash_get_symbol_test) {
   authtable authtab;
 
   sym = pr_stash_get_symbol(0, NULL, NULL, NULL);
-  fail_unless(sym == NULL, "Failed to handle null arguments");
-  fail_unless(errno == EINVAL, "Failed to set errno to EINVAL, got %d (%s)",
+  ck_assert_msg(sym == NULL, "Failed to handle null arguments");
+  ck_assert_msg(errno == EINVAL, "Failed to set errno to EINVAL, got %d (%s)",
     errno, strerror(errno));
 
   sym = pr_stash_get_symbol(0, "foo", NULL, NULL);
-  fail_unless(sym == NULL, "Failed to handle bad type argument");
-  fail_unless(errno == EINVAL, "Failed to set errno to EINVAL, got %d (%s)",
+  ck_assert_msg(sym == NULL, "Failed to handle bad type argument");
+  ck_assert_msg(errno == EINVAL, "Failed to set errno to EINVAL, got %d (%s)",
     errno, strerror(errno));
 
   sym = pr_stash_get_symbol(PR_SYM_CONF, "foo", NULL, NULL);
-  fail_unless(sym == NULL, "Failed to handle nonexistent CONF symbol");
-  fail_unless(errno == ENOENT, "Failed to set errno to ENOENT, got %d (%s)",
+  ck_assert_msg(sym == NULL, "Failed to handle nonexistent CONF symbol");
+  ck_assert_msg(errno == ENOENT, "Failed to set errno to ENOENT, got %d (%s)",
     errno, strerror(errno));
 
   sym = pr_stash_get_symbol(PR_SYM_CMD, "foo", NULL, NULL);
-  fail_unless(sym == NULL, "Failed to handle nonexistent CMD symbol");
-  fail_unless(errno == ENOENT, "Failed to set errno to ENOENT, got %d (%s)",
+  ck_assert_msg(sym == NULL, "Failed to handle nonexistent CMD symbol");
+  ck_assert_msg(errno == ENOENT, "Failed to set errno to ENOENT, got %d (%s)",
     errno, strerror(errno));
 
   sym = pr_stash_get_symbol(PR_SYM_AUTH, "foo", NULL, NULL);
-  fail_unless(sym == NULL, "Failed to handle nonexistent AUTH symbol");
-  fail_unless(errno == ENOENT, "Failed to set errno to ENOENT, got %d (%s)",
+  ck_assert_msg(sym == NULL, "Failed to handle nonexistent AUTH symbol");
+  ck_assert_msg(errno == ENOENT, "Failed to set errno to ENOENT, got %d (%s)",
     errno, strerror(errno));
 
   sym = pr_stash_get_symbol(PR_SYM_HOOK, "foo", NULL, NULL);
-  fail_unless(sym == NULL, "Failed to handle nonexistent HOOK symbol");
-  fail_unless(errno == ENOENT, "Failed to set errno to ENOENT, got %d (%s)",
+  ck_assert_msg(sym == NULL, "Failed to handle nonexistent HOOK symbol");
+  ck_assert_msg(errno == ENOENT, "Failed to set errno to ENOENT, got %d (%s)",
     errno, strerror(errno));
 
   memset(&conftab, 0, sizeof(conftab));
   conftab.directive = pstrdup(p, "foo");
   res = pr_stash_add_symbol(PR_SYM_CONF, &conftab);
-  fail_unless(res == 0, "Failed to add CONF symbol: %s", strerror(errno));
+  ck_assert_msg(res == 0, "Failed to add CONF symbol: %s", strerror(errno));
 
   sym = pr_stash_get_symbol(PR_SYM_CONF, "foo", NULL, NULL);
-  fail_unless(sym != NULL, "Failed to get CONF symbol: %s", strerror(errno));
-  fail_unless(sym == &conftab, "Expected %p, got %p", &conftab, sym);
+  ck_assert_msg(sym != NULL, "Failed to get CONF symbol: %s", strerror(errno));
+  ck_assert_msg(sym == &conftab, "Expected %p, got %p", &conftab, sym);
 
   sym = pr_stash_get_symbol(PR_SYM_CONF, "foo", sym, NULL);
-  fail_unless(sym == NULL, "Unexpectedly found CONF symbol");
-  fail_unless(errno == ENOENT, "Failed to set errno to ENOENT, got %d (%s)",
+  ck_assert_msg(sym == NULL, "Unexpectedly found CONF symbol");
+  ck_assert_msg(errno == ENOENT, "Failed to set errno to ENOENT, got %d (%s)",
     errno, strerror(errno));
 
   memset(&cmdtab, 0, sizeof(cmdtab));
   cmdtab.command = pstrdup(p, "foo");
   res = pr_stash_add_symbol(PR_SYM_CMD, &cmdtab);
-  fail_unless(res == 0, "Failed to add CMD symbol: %s", strerror(errno));
+  ck_assert_msg(res == 0, "Failed to add CMD symbol: %s", strerror(errno));
 
   sym = pr_stash_get_symbol(PR_SYM_CMD, "foo", NULL, NULL);
-  fail_unless(sym != NULL, "Failed to get CMD symbol: %s", strerror(errno));
-  fail_unless(sym == &cmdtab, "Expected %p, got %p", &cmdtab, sym);
+  ck_assert_msg(sym != NULL, "Failed to get CMD symbol: %s", strerror(errno));
+  ck_assert_msg(sym == &cmdtab, "Expected %p, got %p", &cmdtab, sym);
 
   sym = pr_stash_get_symbol(PR_SYM_CMD, "foo", sym, NULL);
-  fail_unless(sym == NULL, "Unexpectedly found CMD symbol");
-  fail_unless(errno == ENOENT, "Failed to set errno to ENOENT, got %d (%s)",
+  ck_assert_msg(sym == NULL, "Unexpectedly found CMD symbol");
+  ck_assert_msg(errno == ENOENT, "Failed to set errno to ENOENT, got %d (%s)",
     errno, strerror(errno));
 
   memset(&authtab, 0, sizeof(authtab));
   authtab.name = pstrdup(p, "foo");
   res = pr_stash_add_symbol(PR_SYM_AUTH, &authtab);
-  fail_unless(res == 0, "Failed to add AUTH symbol: %s", strerror(errno));
+  ck_assert_msg(res == 0, "Failed to add AUTH symbol: %s", strerror(errno));
 
   sym = pr_stash_get_symbol(PR_SYM_AUTH, "foo", NULL, NULL);
-  fail_unless(sym != NULL, "Failed to get AUTH symbol: %s", strerror(errno));
-  fail_unless(sym == &authtab, "Expected %p, got %p", &authtab, sym);
+  ck_assert_msg(sym != NULL, "Failed to get AUTH symbol: %s", strerror(errno));
+  ck_assert_msg(sym == &authtab, "Expected %p, got %p", &authtab, sym);
 
   sym = pr_stash_get_symbol(PR_SYM_AUTH, "foo", sym, NULL);
-  fail_unless(sym == NULL, "Unexpectedly found AUTH symbol");
-  fail_unless(errno == ENOENT, "Failed to set errno to ENOENT, got %d (%s)",
+  ck_assert_msg(sym == NULL, "Unexpectedly found AUTH symbol");
+  ck_assert_msg(errno == ENOENT, "Failed to set errno to ENOENT, got %d (%s)",
     errno, strerror(errno));
 
   memset(&hooktab, 0, sizeof(hooktab));
   hooktab.command = pstrdup(p, "foo");
   res = pr_stash_add_symbol(PR_SYM_HOOK, &hooktab);
-  fail_unless(res == 0, "Failed to add HOOK symbol: %s", strerror(errno));
+  ck_assert_msg(res == 0, "Failed to add HOOK symbol: %s", strerror(errno));
 
   sym = pr_stash_get_symbol(PR_SYM_HOOK, "foo", NULL, NULL);
-  fail_unless(sym != NULL, "Failed to get HOOK symbol: %s", strerror(errno));
-  fail_unless(sym == &hooktab, "Expected %p, got %p", &hooktab, sym);
+  ck_assert_msg(sym != NULL, "Failed to get HOOK symbol: %s", strerror(errno));
+  ck_assert_msg(sym == &hooktab, "Expected %p, got %p", &hooktab, sym);
 
   sym = pr_stash_get_symbol(PR_SYM_HOOK, "foo", sym, NULL);
-  fail_unless(sym == NULL, "Unexpectedly found HOOK symbol");
-  fail_unless(errno == ENOENT, "Failed to set errno to ENOENT, got %d (%s)",
+  ck_assert_msg(sym == NULL, "Unexpectedly found HOOK symbol");
+  ck_assert_msg(errno == ENOENT, "Failed to set errno to ENOENT, got %d (%s)",
     errno, strerror(errno));
 }
 END_TEST
@@ -215,89 +215,89 @@ START_TEST (stash_get_symbol2_test) {
   authtable authtab;
 
   sym = pr_stash_get_symbol2(0, NULL, NULL, NULL, NULL);
-  fail_unless(sym == NULL, "Failed to handle null arguments");
-  fail_unless(errno == EINVAL, "Failed to set errno to EINVAL, got %d (%s)",
+  ck_assert_msg(sym == NULL, "Failed to handle null arguments");
+  ck_assert_msg(errno == EINVAL, "Failed to set errno to EINVAL, got %d (%s)",
     errno, strerror(errno));
 
   sym = pr_stash_get_symbol2(0, "foo", NULL, NULL, NULL);
-  fail_unless(sym == NULL, "Failed to handle bad type argument");
-  fail_unless(errno == EINVAL, "Failed to set errno to EINVAL, got %d (%s)",
+  ck_assert_msg(sym == NULL, "Failed to handle bad type argument");
+  ck_assert_msg(errno == EINVAL, "Failed to set errno to EINVAL, got %d (%s)",
     errno, strerror(errno));
 
   sym = pr_stash_get_symbol2(PR_SYM_CONF, "foo", NULL, NULL, NULL);
-  fail_unless(sym == NULL, "Failed to handle nonexistent CONF symbol");
-  fail_unless(errno == ENOENT, "Failed to set errno to ENOENT, got %d (%s)",
+  ck_assert_msg(sym == NULL, "Failed to handle nonexistent CONF symbol");
+  ck_assert_msg(errno == ENOENT, "Failed to set errno to ENOENT, got %d (%s)",
     errno, strerror(errno));
 
   sym = pr_stash_get_symbol2(PR_SYM_CMD, "foo", NULL, NULL, NULL);
-  fail_unless(sym == NULL, "Failed to handle nonexistent CMD symbol");
-  fail_unless(errno == ENOENT, "Failed to set errno to ENOENT, got %d (%s)",
+  ck_assert_msg(sym == NULL, "Failed to handle nonexistent CMD symbol");
+  ck_assert_msg(errno == ENOENT, "Failed to set errno to ENOENT, got %d (%s)",
     errno, strerror(errno));
 
   sym = pr_stash_get_symbol2(PR_SYM_AUTH, "foo", NULL, NULL, NULL);
-  fail_unless(sym == NULL, "Failed to handle nonexistent AUTH symbol");
-  fail_unless(errno == ENOENT, "Failed to set errno to ENOENT, got %d (%s)",
+  ck_assert_msg(sym == NULL, "Failed to handle nonexistent AUTH symbol");
+  ck_assert_msg(errno == ENOENT, "Failed to set errno to ENOENT, got %d (%s)",
     errno, strerror(errno));
 
   sym = pr_stash_get_symbol2(PR_SYM_HOOK, "foo", NULL, NULL, NULL);
-  fail_unless(sym == NULL, "Failed to handle nonexistent HOOK symbol");
-  fail_unless(errno == ENOENT, "Failed to set errno to ENOENT, got %d (%s)",
+  ck_assert_msg(sym == NULL, "Failed to handle nonexistent HOOK symbol");
+  ck_assert_msg(errno == ENOENT, "Failed to set errno to ENOENT, got %d (%s)",
     errno, strerror(errno));
 
   memset(&conftab, 0, sizeof(conftab));
   conftab.directive = pstrdup(p, "foo");
   res = pr_stash_add_symbol(PR_SYM_CONF, &conftab);
-  fail_unless(res == 0, "Failed to add CONF symbol: %s", strerror(errno));
+  ck_assert_msg(res == 0, "Failed to add CONF symbol: %s", strerror(errno));
 
   sym = pr_stash_get_symbol2(PR_SYM_CONF, "foo", NULL, NULL, NULL);
-  fail_unless(sym != NULL, "Failed to get CONF symbol: %s", strerror(errno));
-  fail_unless(sym == &conftab, "Expected %p, got %p", &conftab, sym);
+  ck_assert_msg(sym != NULL, "Failed to get CONF symbol: %s", strerror(errno));
+  ck_assert_msg(sym == &conftab, "Expected %p, got %p", &conftab, sym);
 
   sym = pr_stash_get_symbol2(PR_SYM_CONF, "foo", sym, NULL, NULL);
-  fail_unless(sym == NULL, "Unexpectedly found CONF symbol");
-  fail_unless(errno == ENOENT, "Failed to set errno to ENOENT, got %d (%s)",
+  ck_assert_msg(sym == NULL, "Unexpectedly found CONF symbol");
+  ck_assert_msg(errno == ENOENT, "Failed to set errno to ENOENT, got %d (%s)",
     errno, strerror(errno));
 
   memset(&cmdtab, 0, sizeof(cmdtab));
   cmdtab.command = pstrdup(p, "foo");
   res = pr_stash_add_symbol(PR_SYM_CMD, &cmdtab);
-  fail_unless(res == 0, "Failed to add CMD symbol: %s", strerror(errno));
+  ck_assert_msg(res == 0, "Failed to add CMD symbol: %s", strerror(errno));
 
   sym = pr_stash_get_symbol2(PR_SYM_CMD, "foo", NULL, NULL, NULL);
-  fail_unless(sym != NULL, "Failed to get CMD symbol: %s", strerror(errno));
-  fail_unless(sym == &cmdtab, "Expected %p, got %p", &cmdtab, sym);
+  ck_assert_msg(sym != NULL, "Failed to get CMD symbol: %s", strerror(errno));
+  ck_assert_msg(sym == &cmdtab, "Expected %p, got %p", &cmdtab, sym);
 
   sym = pr_stash_get_symbol2(PR_SYM_CMD, "foo", sym, NULL, NULL);
-  fail_unless(sym == NULL, "Unexpectedly found CMD symbol");
-  fail_unless(errno == ENOENT, "Failed to set errno to ENOENT, got %d (%s)",
+  ck_assert_msg(sym == NULL, "Unexpectedly found CMD symbol");
+  ck_assert_msg(errno == ENOENT, "Failed to set errno to ENOENT, got %d (%s)",
     errno, strerror(errno));
 
   memset(&authtab, 0, sizeof(authtab));
   authtab.name = pstrdup(p, "foo");
   res = pr_stash_add_symbol(PR_SYM_AUTH, &authtab);
-  fail_unless(res == 0, "Failed to add AUTH symbol: %s", strerror(errno));
+  ck_assert_msg(res == 0, "Failed to add AUTH symbol: %s", strerror(errno));
 
   sym = pr_stash_get_symbol2(PR_SYM_AUTH, "foo", NULL, NULL, NULL);
-  fail_unless(sym != NULL, "Failed to get AUTH symbol: %s", strerror(errno));
-  fail_unless(sym == &authtab, "Expected %p, got %p", &authtab, sym);
+  ck_assert_msg(sym != NULL, "Failed to get AUTH symbol: %s", strerror(errno));
+  ck_assert_msg(sym == &authtab, "Expected %p, got %p", &authtab, sym);
 
   sym = pr_stash_get_symbol2(PR_SYM_AUTH, "foo", sym, NULL, NULL);
-  fail_unless(sym == NULL, "Unexpectedly found AUTH symbol");
-  fail_unless(errno == ENOENT, "Failed to set errno to ENOENT, got %d (%s)",
+  ck_assert_msg(sym == NULL, "Unexpectedly found AUTH symbol");
+  ck_assert_msg(errno == ENOENT, "Failed to set errno to ENOENT, got %d (%s)",
     errno, strerror(errno));
 
   memset(&hooktab, 0, sizeof(hooktab));
   hooktab.command = pstrdup(p, "foo");
   res = pr_stash_add_symbol(PR_SYM_HOOK, &hooktab);
-  fail_unless(res == 0, "Failed to add HOOK symbol: %s", strerror(errno));
+  ck_assert_msg(res == 0, "Failed to add HOOK symbol: %s", strerror(errno));
 
   sym = pr_stash_get_symbol2(PR_SYM_HOOK, "foo", NULL, NULL, NULL);
-  fail_unless(sym != NULL, "Failed to get HOOK symbol: %s", strerror(errno));
-  fail_unless(sym == &hooktab, "Expected %p, got %p", &hooktab, sym);
+  ck_assert_msg(sym != NULL, "Failed to get HOOK symbol: %s", strerror(errno));
+  ck_assert_msg(sym == &hooktab, "Expected %p, got %p", &hooktab, sym);
 
   sym = pr_stash_get_symbol2(PR_SYM_HOOK, "foo", sym, NULL, NULL);
-  fail_unless(sym == NULL, "Unexpectedly found HOOK symbol");
-  fail_unless(errno == ENOENT, "Failed to set errno to ENOENT, got %d (%s)",
+  ck_assert_msg(sym == NULL, "Unexpectedly found HOOK symbol");
+  ck_assert_msg(errno == ENOENT, "Failed to set errno to ENOENT, got %d (%s)",
     errno, strerror(errno));
 }
 END_TEST
@@ -319,17 +319,17 @@ START_TEST (stash_dump_test) {
   memset(&conftab, 0, sizeof(conftab));
   conftab.directive = pstrdup(p, "Conf");
   res = pr_stash_add_symbol(PR_SYM_CONF, &conftab);
-  fail_unless(res == 0, "Failed to add CONF symbol: %s", strerror(errno));
+  ck_assert_msg(res == 0, "Failed to add CONF symbol: %s", strerror(errno));
 
   memset(&cmdtab, 0, sizeof(cmdtab));
   cmdtab.command = pstrdup(p, "Cmd");
   res = pr_stash_add_symbol(PR_SYM_CMD, &cmdtab);
-  fail_unless(res == 0, "Failed to add CMD symbol: %s", strerror(errno));
+  ck_assert_msg(res == 0, "Failed to add CMD symbol: %s", strerror(errno));
 
   memset(&authtab, 0, sizeof(authtab));
   authtab.name = pstrdup(p, "Auth");
   res = pr_stash_add_symbol(PR_SYM_AUTH, &authtab);
-  fail_unless(res == 0, "Failed to add AUTH symbol: %s", strerror(errno));
+  ck_assert_msg(res == 0, "Failed to add AUTH symbol: %s", strerror(errno));
 
   memset(&m, 0, sizeof(m));
   m.name = "testsuite";
@@ -337,22 +337,22 @@ START_TEST (stash_dump_test) {
   hooktab.command = pstrdup(p, "Hook");
   hooktab.m = &m;
   res = pr_stash_add_symbol(PR_SYM_HOOK, &hooktab);
-  fail_unless(res == 0, "Failed to add HOOK symbol: %s", strerror(errno));
+  ck_assert_msg(res == 0, "Failed to add HOOK symbol: %s", strerror(errno));
 
   mark_point();
   pr_stash_dump(stash_dump);
 
   res = pr_stash_remove_symbol(PR_SYM_CONF, "Conf", NULL);
-  fail_unless(res > 0, "Failed to remove CONF symbol: %s", strerror(errno));
+  ck_assert_msg(res > 0, "Failed to remove CONF symbol: %s", strerror(errno));
 
   res = pr_stash_remove_symbol(PR_SYM_CMD, "Cmd", NULL);
-  fail_unless(res > 0, "Failed to remove CMD symbol: %s", strerror(errno));
+  ck_assert_msg(res > 0, "Failed to remove CMD symbol: %s", strerror(errno));
 
   res = pr_stash_remove_symbol(PR_SYM_AUTH, "Auth", NULL);
-  fail_unless(res > 0, "Failed to remove AUTH symbol: %s", strerror(errno));
+  ck_assert_msg(res > 0, "Failed to remove AUTH symbol: %s", strerror(errno));
 
   res = pr_stash_remove_symbol(PR_SYM_HOOK, "Hook", NULL);
-  fail_unless(res > 0, "Failed to remove HOOK symbol: %s", strerror(errno));
+  ck_assert_msg(res > 0, "Failed to remove HOOK symbol: %s", strerror(errno));
 
   mark_point();
   pr_stash_dump(stash_dump);
@@ -367,61 +367,61 @@ START_TEST (stash_remove_symbol_test) {
   authtable authtab;
 
   res = pr_stash_remove_symbol(0, NULL, NULL);
-  fail_unless(res == -1, "Failed to handle null arguments");
-  fail_unless(errno == EINVAL, "Failed to set errno to EINVAL, got %d (%s)",
+  ck_assert_msg(res == -1, "Failed to handle null arguments");
+  ck_assert_msg(errno == EINVAL, "Failed to set errno to EINVAL, got %d (%s)",
     errno, strerror(errno));
 
   res = pr_stash_remove_symbol(0, "foo", NULL);
-  fail_unless(res == -1, "Failed to handle bad symbol type");
-  fail_unless(errno == EINVAL, "Failed to set errno to EINVAL, got %d (%s)",
+  ck_assert_msg(res == -1, "Failed to handle bad symbol type");
+  ck_assert_msg(errno == EINVAL, "Failed to set errno to EINVAL, got %d (%s)",
     errno, strerror(errno));
 
   res = pr_stash_remove_symbol(PR_SYM_CONF, "foo", NULL);
-  fail_unless(res == 0, "Expected %d, got %d", 0, res);
+  ck_assert_msg(res == 0, "Expected %d, got %d", 0, res);
 
   memset(&conftab, 0, sizeof(conftab));
   conftab.directive = pstrdup(p, "foo");
   res = pr_stash_add_symbol(PR_SYM_CONF, &conftab);
-  fail_unless(res == 0, "Failed to add CONF symbol: %s", strerror(errno));
+  ck_assert_msg(res == 0, "Failed to add CONF symbol: %s", strerror(errno));
 
   res = pr_stash_add_symbol(PR_SYM_CONF, &conftab);
-  fail_unless(res == 0, "Failed to add CONF symbol: %s", strerror(errno));
+  ck_assert_msg(res == 0, "Failed to add CONF symbol: %s", strerror(errno));
 
   res = pr_stash_remove_symbol(PR_SYM_CONF, "foo", NULL);
-  fail_unless(res == 2, "Expected %d, got %d", 2, res);
+  ck_assert_msg(res == 2, "Expected %d, got %d", 2, res);
 
   memset(&cmdtab, 0, sizeof(cmdtab));
   cmdtab.command = pstrdup(p, "foo");
   res = pr_stash_add_symbol(PR_SYM_CMD, &cmdtab);
-  fail_unless(res == 0, "Failed to add CMD symbol: %s", strerror(errno));
+  ck_assert_msg(res == 0, "Failed to add CMD symbol: %s", strerror(errno));
 
   res = pr_stash_add_symbol(PR_SYM_CMD, &cmdtab);
-  fail_unless(res == 0, "Failed to add CMD symbol: %s", strerror(errno));
+  ck_assert_msg(res == 0, "Failed to add CMD symbol: %s", strerror(errno));
 
   res = pr_stash_remove_symbol(PR_SYM_CMD, "foo", NULL);
-  fail_unless(res == 2, "Expected %d, got %d", 2, res);
+  ck_assert_msg(res == 2, "Expected %d, got %d", 2, res);
 
   memset(&authtab, 0, sizeof(authtab));
   authtab.name = pstrdup(p, "foo");
   res = pr_stash_add_symbol(PR_SYM_AUTH, &authtab);
-  fail_unless(res == 0, "Failed to add AUTH symbol: %s", strerror(errno));
+  ck_assert_msg(res == 0, "Failed to add AUTH symbol: %s", strerror(errno));
 
   res = pr_stash_add_symbol(PR_SYM_AUTH, &authtab);
-  fail_unless(res == 0, "Failed to add AUTH symbol: %s", strerror(errno));
+  ck_assert_msg(res == 0, "Failed to add AUTH symbol: %s", strerror(errno));
 
   res = pr_stash_remove_symbol(PR_SYM_AUTH, "foo", NULL);
-  fail_unless(res == 2, "Expected %d, got %d", 2, res);
+  ck_assert_msg(res == 2, "Expected %d, got %d", 2, res);
 
   memset(&hooktab, 0, sizeof(hooktab));
   hooktab.command = pstrdup(p, "foo");
   res = pr_stash_add_symbol(PR_SYM_HOOK, &hooktab);
-  fail_unless(res == 0, "Failed to add HOOK symbol: %s", strerror(errno));
+  ck_assert_msg(res == 0, "Failed to add HOOK symbol: %s", strerror(errno));
 
   res = pr_stash_add_symbol(PR_SYM_HOOK, &hooktab);
-  fail_unless(res == 0, "Failed to add HOOK symbol: %s", strerror(errno));
+  ck_assert_msg(res == 0, "Failed to add HOOK symbol: %s", strerror(errno));
 
   res = pr_stash_remove_symbol(PR_SYM_HOOK, "foo", NULL);
-  fail_unless(res == 2, "Expected %d, got %d", 2, res);
+  ck_assert_msg(res == 2, "Expected %d, got %d", 2, res);
 }
 END_TEST
 
@@ -430,23 +430,23 @@ START_TEST (stash_remove_conf_test) {
   conftable conftab;
 
   res = pr_stash_remove_conf(NULL, NULL);
-  fail_unless(res == -1, "Failed to handle null arguments");
-  fail_unless(errno == EINVAL, "Failed to set errno to EINVAL, got %d (%s)",
+  ck_assert_msg(res == -1, "Failed to handle null arguments");
+  ck_assert_msg(errno == EINVAL, "Failed to set errno to EINVAL, got %d (%s)",
     errno, strerror(errno));
 
   res = pr_stash_remove_conf("foo", NULL);
-  fail_unless(res == 0, "Expected %d, got %d", 0, res);
+  ck_assert_msg(res == 0, "Expected %d, got %d", 0, res);
 
   memset(&conftab, 0, sizeof(conftab));
   conftab.directive = pstrdup(p, "foo");
   res = pr_stash_add_symbol(PR_SYM_CONF, &conftab);
-  fail_unless(res == 0, "Failed to add CONF symbol: %s", strerror(errno));
+  ck_assert_msg(res == 0, "Failed to add CONF symbol: %s", strerror(errno));
 
   res = pr_stash_add_symbol(PR_SYM_CONF, &conftab);
-  fail_unless(res == 0, "Failed to add CONF symbol: %s", strerror(errno));
+  ck_assert_msg(res == 0, "Failed to add CONF symbol: %s", strerror(errno));
 
   res = pr_stash_remove_conf("foo", NULL);
-  fail_unless(res == 2, "Expected %d, got %d", 2, res);
+  ck_assert_msg(res == 2, "Expected %d, got %d", 2, res);
 }
 END_TEST
 
@@ -455,25 +455,25 @@ START_TEST (stash_remove_cmd_test) {
   cmdtable cmdtab, cmdtab2;
 
   res = pr_stash_remove_cmd(NULL, NULL, 0, NULL, -1);
-  fail_unless(res == -1, "Failed to handle null arguments");
-  fail_unless(errno == EINVAL, "Failed to set errno to EINVAL, got %d (%s)",
+  ck_assert_msg(res == -1, "Failed to handle null arguments");
+  ck_assert_msg(errno == EINVAL, "Failed to set errno to EINVAL, got %d (%s)",
     errno, strerror(errno));
 
   res = pr_stash_remove_cmd("foo", NULL, 0, NULL, -1);
-  fail_unless(res == 0, "Expected %d, got %d", 0, res);
+  ck_assert_msg(res == 0, "Expected %d, got %d", 0, res);
 
   memset(&cmdtab, 0, sizeof(cmdtab));
   cmdtab.command = pstrdup(p, "foo");
   res = pr_stash_add_symbol(PR_SYM_CMD, &cmdtab);
-  fail_unless(res == 0, "Failed to add CMD symbol: %s", strerror(errno));
+  ck_assert_msg(res == 0, "Failed to add CMD symbol: %s", strerror(errno));
 
   memset(&cmdtab2, 0, sizeof(cmdtab2));
   cmdtab2.command = pstrdup(p, "foo");
   res = pr_stash_add_symbol(PR_SYM_CMD, &cmdtab2);
-  fail_unless(res == 0, "Failed to add CMD symbol: %s", strerror(errno));
+  ck_assert_msg(res == 0, "Failed to add CMD symbol: %s", strerror(errno));
 
   res = pr_stash_remove_cmd("foo", NULL, 0, NULL, -1);
-  fail_unless(res == 2, "Expected %d, got %d", 2, res);
+  ck_assert_msg(res == 2, "Expected %d, got %d", 2, res);
 
   /* Remove only the PRE_CMD cmd handlers */
   mark_point();
@@ -481,17 +481,17 @@ START_TEST (stash_remove_cmd_test) {
   cmdtab.command = pstrdup(p, "foo");
   cmdtab.cmd_type = PRE_CMD;
   res = pr_stash_add_symbol(PR_SYM_CMD, &cmdtab);
-  fail_unless(res == 0, "Failed to add CMD symbol: %s", strerror(errno));
+  ck_assert_msg(res == 0, "Failed to add CMD symbol: %s", strerror(errno));
 
   memset(&cmdtab2, 0, sizeof(cmdtab2));
   cmdtab2.command = pstrdup(p, "foo");
   cmdtab2.cmd_type = CMD;
   res = pr_stash_add_symbol(PR_SYM_CMD, &cmdtab2);
-  fail_unless(res == 0, "Failed to add CMD symbol: %s", strerror(errno));
+  ck_assert_msg(res == 0, "Failed to add CMD symbol: %s", strerror(errno));
 
   mark_point();
   res = pr_stash_remove_cmd("foo", NULL, PRE_CMD, NULL, -1);
-  fail_unless(res == 1, "Expected %d, got %d", 1, res);
+  ck_assert_msg(res == 1, "Expected %d, got %d", 1, res);
   (void) pr_stash_remove_symbol(PR_SYM_CMD, "foo", NULL);
 
   /* Remove only the G_WRITE cmd handlers */
@@ -500,16 +500,16 @@ START_TEST (stash_remove_cmd_test) {
   cmdtab.command = pstrdup(p, "foo");
   cmdtab.group = G_WRITE;
   res = pr_stash_add_symbol(PR_SYM_CMD, &cmdtab);
-  fail_unless(res == 0, "Failed to add CMD symbol: %s", strerror(errno));
+  ck_assert_msg(res == 0, "Failed to add CMD symbol: %s", strerror(errno));
 
   memset(&cmdtab2, 0, sizeof(cmdtab2));
   cmdtab2.command = pstrdup(p, "foo");
   res = pr_stash_add_symbol(PR_SYM_CMD, &cmdtab2);
-  fail_unless(res == 0, "Failed to add CMD symbol: %s", strerror(errno));
+  ck_assert_msg(res == 0, "Failed to add CMD symbol: %s", strerror(errno));
 
   mark_point();
   res = pr_stash_remove_cmd("foo", NULL, 0, G_WRITE, -1);
-  fail_unless(res == 1, "Expected %d, got %d", 1, res);
+  ck_assert_msg(res == 1, "Expected %d, got %d", 1, res);
   (void) pr_stash_remove_symbol(PR_SYM_CMD, "foo", NULL);
 
   /* Remove only the CL_SFTP cmd handlers */
@@ -518,17 +518,17 @@ START_TEST (stash_remove_cmd_test) {
   cmdtab.command = pstrdup(p, "foo");
   cmdtab.cmd_class = CL_SFTP;
   res = pr_stash_add_symbol(PR_SYM_CMD, &cmdtab);
-  fail_unless(res == 0, "Failed to add CMD symbol: %s", strerror(errno));
+  ck_assert_msg(res == 0, "Failed to add CMD symbol: %s", strerror(errno));
 
   memset(&cmdtab2, 0, sizeof(cmdtab2));
   cmdtab2.command = pstrdup(p, "foo");
   cmdtab2.cmd_class = CL_MISC;
   res = pr_stash_add_symbol(PR_SYM_CMD, &cmdtab2);
-  fail_unless(res == 0, "Failed to add CMD symbol: %s", strerror(errno));
+  ck_assert_msg(res == 0, "Failed to add CMD symbol: %s", strerror(errno));
 
   mark_point();
   res = pr_stash_remove_cmd("foo", NULL, 0, NULL, CL_SFTP);
-  fail_unless(res == 1, "Expected %d, got %d", 1, res);
+  ck_assert_msg(res == 1, "Expected %d, got %d", 1, res);
   (void) pr_stash_remove_symbol(PR_SYM_CMD, "foo", NULL);
 }
 END_TEST
@@ -538,23 +538,23 @@ START_TEST (stash_remove_auth_test) {
   authtable authtab;
 
   res = pr_stash_remove_auth(NULL, NULL);
-  fail_unless(res == -1, "Failed to handle null arguments");
-  fail_unless(errno == EINVAL, "Failed to set errno to EINVAL, got %d (%s)",
+  ck_assert_msg(res == -1, "Failed to handle null arguments");
+  ck_assert_msg(errno == EINVAL, "Failed to set errno to EINVAL, got %d (%s)",
     errno, strerror(errno));
 
   res = pr_stash_remove_auth("foo", NULL);
-  fail_unless(res == 0, "Expected %d, got %d", 0, res);
+  ck_assert_msg(res == 0, "Expected %d, got %d", 0, res);
 
   memset(&authtab, 0, sizeof(authtab));
   authtab.name = pstrdup(p, "foo");
   res = pr_stash_add_symbol(PR_SYM_AUTH, &authtab);
-  fail_unless(res == 0, "Failed to add AUTH symbol: %s", strerror(errno));
+  ck_assert_msg(res == 0, "Failed to add AUTH symbol: %s", strerror(errno));
 
   res = pr_stash_add_symbol(PR_SYM_AUTH, &authtab);
-  fail_unless(res == 0, "Failed to add AUTH symbol: %s", strerror(errno));
+  ck_assert_msg(res == 0, "Failed to add AUTH symbol: %s", strerror(errno));
 
   res = pr_stash_remove_auth("foo", NULL);
-  fail_unless(res == 2, "Expected %d, got %d", 2, res);
+  ck_assert_msg(res == 2, "Expected %d, got %d", 2, res);
 }
 END_TEST
 
@@ -563,23 +563,23 @@ START_TEST (stash_remove_hook_test) {
   cmdtable hooktab;
 
   res = pr_stash_remove_hook(NULL, NULL);
-  fail_unless(res == -1, "Failed to handle null arguments");
-  fail_unless(errno == EINVAL, "Failed to set errno to EINVAL, got %d (%s)",
+  ck_assert_msg(res == -1, "Failed to handle null arguments");
+  ck_assert_msg(errno == EINVAL, "Failed to set errno to EINVAL, got %d (%s)",
     errno, strerror(errno));
 
   res = pr_stash_remove_hook("foo", NULL);
-  fail_unless(res == 0, "Expected %d, got %d", 0, res);
+  ck_assert_msg(res == 0, "Expected %d, got %d", 0, res);
 
   memset(&hooktab, 0, sizeof(hooktab));
   hooktab.command = pstrdup(p, "foo");
   res = pr_stash_add_symbol(PR_SYM_HOOK, &hooktab);
-  fail_unless(res == 0, "Failed to add HOOK symbol: %s", strerror(errno));
+  ck_assert_msg(res == 0, "Failed to add HOOK symbol: %s", strerror(errno));
 
   res = pr_stash_add_symbol(PR_SYM_HOOK, &hooktab);
-  fail_unless(res == 0, "Failed to add HOOK symbol: %s", strerror(errno));
+  ck_assert_msg(res == 0, "Failed to add HOOK symbol: %s", strerror(errno));
 
   res = pr_stash_remove_hook("foo", NULL);
-  fail_unless(res == 2, "Expected %d, got %d", 2, res);
+  ck_assert_msg(res == 2, "Expected %d, got %d", 2, res);
 }
 END_TEST
 
